@@ -11,6 +11,6 @@ from .language import BaseRenderer
 
 # Set version number.
 try:
-	__version__ = get_distribution(__name__).version
+    __version__ = get_distribution(__name__).version
 except DistributionNotFound:
-	__version__ = ""
+    pass
